A library for developing ERC20 tokens for the Casper network.
The main functionality is provided via the ERC20 struct, and is intended to be consumed by a
smart contract written to be deployed on the Casper network.
To create an example ERC20 contract which uses this library, use the cargo-casper tool:
cargo install cargo-casper
cargo casper --erc20 <PATH TO NEW PROJECT>Re-exports
pub use address::Address;
Modules
- address
- Implementation of an
Addresswhich refers either an account hash, or a contract hash. - constants
- Constants used by the ERC20 contract.
- entry_
points - Contains definition of the entry points.
Structs
- ERC20
- Implementation of ERC20 standard functionality.
Enums
- Error
- Errors which can be returned by the library.